pub struct TableJoin;Expand description
Table join operations.
Implementations
Sourceimpl TableJoin
impl TableJoin
Sourcepub fn hash_join(
left: &InMemoryTable,
right: &InMemoryTable,
left_key: &str,
right_key: &str,
join_type: JoinType,
) -> Result<InMemoryTable>
pub fn hash_join( left: &InMemoryTable, right: &InMemoryTable, left_key: &str, right_key: &str, join_type: JoinType, ) -> Result<InMemoryTable>
Hash join two tables on the given key columns.
Sourcepub fn merge_join(
left: &InMemoryTable,
right: &InMemoryTable,
left_key: &str,
right_key: &str,
) -> Result<InMemoryTable>
pub fn merge_join( left: &InMemoryTable, right: &InMemoryTable, left_key: &str, right_key: &str, ) -> Result<InMemoryTable>
Merge join two pre-sorted tables on the given key columns. Both tables must already be sorted ascending by their key columns.