pub struct QueryResult {
pub rows: Vec<Row>,
pub columns: Vec<String>,
pub n_rows: usize,
}Expand description
The result of executing a DataQuery.
Fields
rows: Vec<Row>All matching rows after projection, filtering, ordering and limiting.
columns: Vec<String>Column names present in the result rows (in projection order).
n_rows: usizeTotal number of result rows (equals rows.len()).
Implementations
Sourceimpl QueryResult
impl QueryResult
Sourcepub fn agg(&self) -> Aggregations<'_>
pub fn agg(&self) -> Aggregations<'_>
Return an Aggregations helper bound to this result.
Sourcepub fn group_by(self, column: &str) -> GroupedResult
pub fn group_by(self, column: &str) -> GroupedResult
Group rows by the string representation of the given column’s values.