pub struct TransposeCodec { /* private fields */ }Expand description
Transpose codec: reorders array elements between C-order and F-order.
For simplicity this operates on the raw byte buffer by transposing element indices according to the chunk shape.
Implementations