pub struct ZarrArray { /* private fields */ }Expand description
A chunked N-dimensional array stored in a Zarr directory store.
Implementations
Sourceimpl ZarrArray
impl ZarrArray
Sourcepub fn create(
store: DirectoryStore,
path: &str,
shape: Vec<u64>,
chunks: Vec<u64>,
dtype: DataType,
version: ZarrVersion,
) -> Result<Self>
pub fn create( store: DirectoryStore, path: &str, shape: Vec<u64>, chunks: Vec<u64>, dtype: DataType, version: ZarrVersion, ) -> Result<Self>
Create a new Zarr array.
Sourcepub fn create_with_options(
store: DirectoryStore,
path: &str,
shape: Vec<u64>,
chunks: Vec<u64>,
dtype: DataType,
version: ZarrVersion,
fill_value: f64,
compress: bool,
) -> Result<Self>
pub fn create_with_options( store: DirectoryStore, path: &str, shape: Vec<u64>, chunks: Vec<u64>, dtype: DataType, version: ZarrVersion, fill_value: f64, compress: bool, ) -> Result<Self>
Create a new Zarr array with explicit fill value and compression option.
Sourcepub fn open(store: DirectoryStore, path: &str) -> Result<Self>
pub fn open(store: DirectoryStore, path: &str) -> Result<Self>
Open an existing Zarr array from a store.
Sourcepub fn chunk_shape(&self) -> &[u64]
pub fn chunk_shape(&self) -> &[u64]
Chunk shape.
Sourcepub fn version(&self) -> ZarrVersion
pub fn version(&self) -> ZarrVersion
Zarr version.
Sourcepub fn num_chunks(&self) -> Vec<u64>
pub fn num_chunks(&self) -> Vec<u64>
Number of chunks along each dimension.
Sourcepub fn read_chunk(&self, coords: &[u64]) -> Result<Vec<f64>>
pub fn read_chunk(&self, coords: &[u64]) -> Result<Vec<f64>>
Read a single chunk. Returns fill values if the chunk does not exist.