pub struct MsgPackWriter { /* private fields */ }Expand description
Low-level MessagePack writer.
Push individual values into an internal buffer, then call MsgPackWriter::into_bytes
to get the encoded byte slice.
Example
use scirs2_io::formats::msgpack::{MsgPackWriter, MsgPackReader};
let mut w = MsgPackWriter::new();
w.write_map_header(1);
w.write_str("answer");
w.write_int(42);
let bytes = w.into_bytes();
let mut r = MsgPackReader::new(&bytes);
let value = r.read_value().expect("decode failed");Implementations
Sourceimpl MsgPackWriter
impl MsgPackWriter
Sourcepub fn into_bytes(self) -> Vec<u8> ⓘ
pub fn into_bytes(self) -> Vec<u8> ⓘ
Consume the writer and return the encoded bytes.
Sourcepub fn write_bool(&mut self, v: bool)
pub fn write_bool(&mut self, v: bool)
Write a boolean value.
Sourcepub fn write_int(&mut self, v: i64)
pub fn write_int(&mut self, v: i64)
Write a signed integer using the smallest possible representation.
Sourcepub fn write_uint(&mut self, v: u64)
pub fn write_uint(&mut self, v: u64)
Write an unsigned integer using the smallest possible representation.
Sourcepub fn write_float(&mut self, v: f64)
pub fn write_float(&mut self, v: f64)
Write a 64-bit float (f64).
Sourcepub fn write_float32(&mut self, v: f32)
pub fn write_float32(&mut self, v: f32)
Write a 32-bit float (f32).
Sourcepub fn write_array_header(&mut self, n: usize)
pub fn write_array_header(&mut self, n: usize)
Write an array header. You must write exactly n elements after this call.
Sourcepub fn write_map_header(&mut self, n: usize)
pub fn write_map_header(&mut self, n: usize)
Write a map header. You must write exactly n key-value pairs after this call.
Sourcepub fn write_value(&mut self, value: &MsgPackValue)
pub fn write_value(&mut self, value: &MsgPackValue)
Recursively write a MsgPackValue.