pub struct TileDBArray { /* private fields */ }Expand description
A TileDB array supporting dense and sparse storage.
Data is organized into tiles for efficient I/O. Dense arrays store all cells within dimension bounds; sparse arrays store only occupied cells with explicit coordinates.
Implementations
Sourceimpl TileDBArray
impl TileDBArray
Sourcepub fn create(
schema: ArraySchema,
config: TileDBConfig,
) -> Result<Self, TileDBError>
pub fn create( schema: ArraySchema, config: TileDBConfig, ) -> Result<Self, TileDBError>
Create a new TileDB array from a schema.
Sourcepub fn schema(&self) -> &ArraySchema
pub fn schema(&self) -> &ArraySchema
Return the schema of this array.
Sourcepub fn config(&self) -> &TileDBConfig
pub fn config(&self) -> &TileDBConfig
Return the config of this array.
Sourcepub fn write_dense(
&mut self,
data: &[f64],
subarray: &[(usize, usize)],
) -> Result<(), TileDBError>
pub fn write_dense( &mut self, data: &[f64], subarray: &[(usize, usize)], ) -> Result<(), TileDBError>
Write data to a dense subarray.
data contains the values to write in row-major order.
subarray defines the range for each dimension as (start, end) inclusive.
Sourcepub fn read_dense(
&self,
subarray: &[(usize, usize)],
) -> Result<Vec<f64>, TileDBError>
pub fn read_dense( &self, subarray: &[(usize, usize)], ) -> Result<Vec<f64>, TileDBError>
Read data from a dense subarray.
subarray defines the range for each dimension as (start, end) inclusive.
Returns data in row-major order.
Sourcepub fn write_sparse(
&mut self,
coords: &[Vec<f64>],
values: &[f64],
) -> Result<(), TileDBError>
pub fn write_sparse( &mut self, coords: &[Vec<f64>], values: &[f64], ) -> Result<(), TileDBError>
Write sparse data to the array.
coords is a slice of coordinate vectors (one per dimension).
values contains the attribute values for each coordinate tuple.
Sourcepub fn read_sparse(
&self,
query_range: &[(f64, f64)],
) -> Result<(Vec<Vec<f64>>, Vec<f64>), TileDBError>
pub fn read_sparse( &self, query_range: &[(f64, f64)], ) -> Result<(Vec<Vec<f64>>, Vec<f64>), TileDBError>
Read sparse data within a range query.
query_range defines the (min, max) range for each dimension.
Returns (coordinates, values) for all cells within the range.
Sourcepub fn total_capacity(&self) -> usize
pub fn total_capacity(&self) -> usize
Return the total capacity of the dense array.